@@ -4,9 +4,14 @@
     anonymous_parameters,
     arithmetic_overflow,
     array_into_iter,
+    asm_sub_register,
     bindings_with_variant_name,
+    broken_intra_doc_links,
+    cenum_impl_drop_cast,
+    clashing_extern_declarations,
     coherence_leak_check,
     conflicting_repr_hints,
+    confusable_idents,
     const_err,
     dead_code,
     deprecated,
@@ -17,10 +22,12 @@
     ill_formed_attribute_input,
     illegal_floating_point_literal_pattern,
     improper_ctypes,
+    improper_ctypes_definitions,
     incomplete_features,
+    incomplete_include,
     indirect_structural_match,
     inline_no_sanitize,
-    invalid_codeblock_attribute,
+    invalid_codeblock_attributes,
     invalid_type_param_default,
     invalid_value,
     irrefutable_let_patterns,
@@ -31,7 +38,7 @@
     missing_copy_implementations,
     missing_crate_level_docs,
     missing_docs,
-    missing_fragment_specifier,
+    mixed_script_confusables,
     mutable_borrow_reservation_conflict,
     mutable_transmutes,
     no_mangle_const_items,
@@ -59,6 +66,7 @@
     trivial_numeric_casts,
     type_alias_bounds,
     tyvar_behind_raw_pointer,
+    unaligned_references,
     uncommon_codepoints,
     unconditional_panic,
     unconditional_recursion,
@@ -75,6 +83,7 @@
     unused_attributes,
     unused_braces,
     unused_comparisons,
+    unused_crate_dependencies,
     unused_doc_comments,
     unused_extern_crates,
     unused_features,
@@ -89,15 +98,13 @@
     unused_qualifications,
     unused_unsafe,
     unused_variables,
-    where_clauses_object_safety,
-    while_true
+    where_clauses_object_safety
 )]
 #![warn(macro_use_extern_crate, unknown_lints)]
 #![allow(
     bare_trait_objects,
     box_pointers,
     elided_lifetimes_in_paths,
-    intra_doc_link_resolution_failure,
     missing_doc_code_examples,
     missing_debug_implementations,
     single_use_lifetimes,
